package com.yiqi.app.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.app.domain.AppNotify;

/**
 * 消息通知Mapper接口
 *
 * @author xiaohei
 * @date 2023-09-01
 */
@Mapper
public interface AppNotifyMapper extends BaseMapper<AppNotify> {
    /**
     * 查询消息通知
     *
     * @param id 消息通知主键
     * @return 消息通知
     */
    public AppNotify selectAppNotifyById(Long id);

    /**
     * 查询消息通知列表
     *
     * @param appNotify 消息通知
     * @return 消息通知集合
     */
    public List<AppNotify> selectAppNotifyList(AppNotify appNotify);

    /**
     * 新增消息通知
     *
     * @param appNotify 消息通知
     * @return 结果
     */
    public int insertAppNotify(AppNotify appNotify);

    /**
     * 修改消息通知
     *
     * @param appNotify 消息通知
     * @return 结果
     */
    public int updateAppNotify(AppNotify appNotify);

    /**
     * 删除消息通知
     *
     * @param id 消息通知主键
     * @return 结果
     */
    public int deleteAppNotifyById(Long id);

    /**
     * 批量删除消息通知
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppNotifyByIds(Long[] ids);
}
