package com.yiqi.admin.controller.app;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.yiqi.common.constant.UrlConstants;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.app.domain.AppNotify;
import com.yiqi.app.service.IAppNotifyService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * 消息通知Controller
 *
 * @author xiaohei
 * @date 2023-09-01
 */
@Api(tags = "管理后台 - 消息通知")
@RestController
@RequestMapping(UrlConstants.managerApi + "/app/notify")
public class AppNotifyController extends BaseController {
    @Autowired
    private IAppNotifyService appNotifyService;

    /**
     * 查询消息通知列表
     */
    @PreAuthorize("@ss.hasPermi('app:notify:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询消息通知列表")
    public TableDataInfo list(AppNotify appNotify) {
        startPage();
        List<AppNotify> list = appNotifyService.selectAppNotifyList(appNotify);
        return getDataTable(list);
    }

    /**
     * 导出消息通知列表
     */
    @PreAuthorize("@ss.hasPermi('app:notify:export')")
    @Log(title = "消息通知", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出消息通知列表")
    public void export(HttpServletResponse response, AppNotify appNotify) {
        List<AppNotify> list = appNotifyService.selectAppNotifyList(appNotify);
        ExcelUtil<AppNotify> util = new ExcelUtil<AppNotify>(AppNotify. class);
        util.exportExcel(response, list, "消息通知数据");
    }

    /**
     * 获取消息通知详细信息
     */
    @PreAuthorize("@ss.hasPermi('app:notify:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取消息通知详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(appNotifyService.selectAppNotifyById(id));
    }

    /**
     * 新增消息通知
     */
    @PreAuthorize("@ss.hasPermi('app:notify:add')")
    @Log(title = "消息通知", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增消息通知")
    public AjaxResult add(@RequestBody AppNotify appNotify) {
        appNotify.setCreateById(getUserId());
        appNotify.setCreateBy(getUsername());
        return toAjax(appNotifyService.insertAppNotify(appNotify));
    }

    /**
     * 修改消息通知
     */
    @PreAuthorize("@ss.hasPermi('app:notify:edit')")
    @Log(title = "消息通知", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改消息通知")
    public AjaxResult edit(@RequestBody AppNotify appNotify) {
        appNotify.setUpdateById(getUserId());
        appNotify.setUpdateBy(getUsername());
        return toAjax(appNotifyService.updateAppNotify(appNotify));
    }

    /**
     * 删除消息通知
     */
    @PreAuthorize("@ss.hasPermi('app:notify:remove')")
    @Log(title = "消息通知", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除消息通知")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(appNotifyService.deleteAppNotifyByIds(ids));
    }

}
